.. ParMOO documentation master file

.. image:: img/logo-ParMOO.svg
    :align: center
    :alt: ParMOO

|

ParMOO: Python library for parallel multiobjective simulation optimization
==========================================================================

ParMOO is a Python library for solving multiobjective simulation-based
optimization problems, while exploiting problem structure.

ParMOO stands for "parallel multiobjective optimization".
ParMOO can be used to solve multiobjective optimization problems (MOOPs)
or to generate batches of simulation inputs for parallel evaluation.

ParMOO is intended for scientists, engineers, optimizers, and other
practitioners, who are looking to build or use custom solvers for
computationally expensive multiobjective problems.

**As of version 0.4.0: we are integrating with jax!**

If you're new to ParMOO:

 * Check out the :ref:`Quickstart`
 * Try some of our :doc:`Basic Tutorials <tutorials/basic-tutorials>`
 * Try :doc:`Running in Parallel using libEnsemble <extras>`
 * Check us out on `GitHub <https://github.com/parmoo/parmoo>`_

Table of Contents
=================

.. toctree::
   :maxdepth: 2
   :caption: User Guide:

   quickstart
   install
   about
   how-to-write
   extras
   jax-tips
   faqs
   refs

.. toctree::
   :maxdepth: 2
   :caption: API:

   api

.. toctree::
   :maxdepth: 2
   :caption: Tutorials:

   tutorials/basic-tutorials
   tutorials/libe-tutorial
   tutorials/local_method

.. toctree::
   :maxdepth: 2
   :caption: Developer Guide:

   dev-guide/contributing
   dev-guide/release-proc
   dev-guide/release-notes
   dev-guide/modules

Indices:
========

 * :ref:`genindex`
 * :ref:`modindex`
